class CorpusDisplay extends RessourceDisplay {
  constructor(displayElement) {
    super(displayElement);
    this.corpus = undefined;
    this.user.eventListeners.corpus.addEventListener((eventType, payload) => this.eventHandler(eventType, payload), displayElement.dataset.corpusId);
  }

  init(corpus) {
    this.corpus = corpus;
    this.setCreationDate(this.corpus.creation_date);
    this.setDescription(this.corpus.description);
    this.setLastEditedDate(this.corpus.last_edited_date);
    this.setStatus(this.corpus.status);
    this.setTitle(this.corpus.title);
    this.setTokenRatio(this.corpus.current_nr_of_tokens, this.corpus.max_nr_of_tokens);
  }

  patch(patch) {
    let re;
    for (let operation of patch) {
      switch(operation.op) {
        case 'replace':
          // Matches: /jobs/{this.job.id}/status
          re = new RegExp('^/corpora/' + this.corpus.id + '/last_edited_date');
          if (re.test(operation.path)) {this.setLastEditedDate(operation.value); break;}
          // Matches: /jobs/{this.job.id}/status
          re = new RegExp('^/corpora/' + this.corpus.id + '/status$');
          if (re.test(operation.path)) {this.setStatus(operation.value); break;}
          break;
        default:
          break;
      }
    }
  }

  setTitle(title) {
    for (let element of this.displayElement.querySelectorAll('.corpus-title')) {this.setElement(element, title);}
  }

  setTokenRatio(currentNrOfTokens, maxNrOfTokens) {
    let tokenRatio = `${currentNrOfTokens}/${maxNrOfTokens}`;
    for (let element of this.displayElement.querySelectorAll('.corpus-token-ratio')) {this.setElement(element, tokenRatio);}
  }

  setDescription(description) {
    for (let element of this.displayElement.querySelectorAll('.corpus-description')) {this.setElement(element, description);}
  }

  setStatus(status) {
    for (let element of this.displayElement.querySelectorAll('.analyse-corpus-trigger')) {
      if (['analysing', 'prepared', 'start analysis'].includes(status)) {
        element.classList.remove('disabled');
      } else {
        element.classList.add('disabled');
      }
    }
    for (let element of this.displayElement.querySelectorAll('.build-corpus-trigger')) {
      if (status === 'unprepared') {
        element.classList.remove('disabled');
      } else {
        element.classList.add('disabled');
      }
    }
    for (let element of this.displayElement.querySelectorAll('.corpus-status')) {this.setElement(element, status);}
    for (let element of this.displayElement.querySelectorAll('.status')) {element.dataset.status = status;}
    for (let element of this.displayElement.querySelectorAll('.status-spinner')) {
      if (['submitted', 'queued', 'running', 'canceling', 'start analysis', 'stop analysis'].includes(status)) {
        element.classList.remove('hide');
      } else {
        element.classList.add('hide');
      }
    }
  }

  setCreationDate(creationDateTimestamp) {
    let creationDate = new Date(creationDateTimestamp * 1000).toLocaleString("en-US");
    for (let element of this.displayElement.querySelectorAll('.corpus-creation-date')) {this.setElement(element, creationDate);}
  }

  setLastEditedDate(endDateTimestamp) {
    let endDate = new Date(endDateTimestamp * 1000).toLocaleString("en-US");
    for (let element of this.displayElement.querySelectorAll('.corpus-end-date')) {this.setElement(element, endDate);}
  }
}
